SQLAlchemy Converter
=====================

``inverter`` provides converter from ``dataclass`` to `SQLAlchemy <http://docs.sqlalchemy.org>`_ ORM model.

Currently, only PostgreSQL compatible model is can be generated. 

.. autofunction:: inverter.dc2pgsqla.convert
